Face Lensing App
================

Look at yourself through a gravitational lens. 

Installation
------------

1. Install the Python program with `pip`
    ```sh
    pip install face_lensing
    ```
2. Launch the app from a terminal
    ```sh
    face-lensing-app
    ```
3. A window should appear with the distorted webcam image


App controls
------------

The app can be controlled through the keyboard using the following controls:

- <kbd>Q</kbd>: quit the program
- <kbd>C</kbd>: change camera (in case of multiple webcams)
- <kbd>J</kbd>: increase the lensing effect
- <kbd>K</kbd>: decrease the lensing effect


License
-------

This program is licensed under the MIT license.
